package net.flashii.mcexts.mixin;

import java.net.SocketAddress;
import com.mojang.authlib.GameProfile;
import net.flashii.mcexts.RPC;
import net.flashii.mcexts.RPCPayload;
import net.minecraft.server.PlayerManager;
import net.minecraft.text.Text;
import net.minecraft.util.Formatting;
import org.spongepowered.asm.mixin.Mixin;
import org.spongepowered.asm.mixin.injection.At;
import org.spongepowered.asm.mixin.injection.Inject;
import org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable;

@Mixin(PlayerManager.class)
public abstract class PlayerManagerMixin {
    @Inject(method = "checkCanJoin(Ljava/net/SocketAddress;Lcom/mojang/authlib/GameProfile;)Lnet/minecraft/text/Text;", at = @At("HEAD"), cancellable = true)
    private void checkCanJoin(SocketAddress sockAddr, GameProfile profile, CallbackInfoReturnable<Text> cir) {
        Text authText = null;

        try {
            RPCPayload payload = RPC.postAuth(profile.getId(), profile.getName(), sockAddr);

            if(!payload.is("auth:ok")) {
                if(payload.is("error")) {
                    authText = Text.literal(
                        payload.getAttrStr(payload.hasAttr("text") ? "text" : "code")
                    ).formatted(Formatting.RED);
                } else if(payload.is("auth:authorise")) {
                    String userName = payload.getAttrStr("user_name");
                    int userColour = payload.hasAttr("user_colour") ? payload.getAttrInt("user_colour") : 0xFFFFFF;
                    String url = payload.getAttrStr("url");

                    authText = Text.literal("Welcome back, ")
                        .append(Text.literal(userName).styled(style -> style.withColor(userColour).withBold(true)))
                        .append(Text.literal("!\n\n"))
                        .append(Text.literal("Please go to "))
                        .append(Text.literal(url).formatted(Formatting.BLUE))
                        .append(Text.literal(" in your web browser to verify that it is actually you that is connecting.\n\n"))
                        .append(Text.literal("After you've approved the attempt, connect to the server again and you should be good to go."));
                } else if(payload.is("auth:link")) {
                    String code = payload.getAttrStr("code");
                    String url = payload.getAttrStr("url");

                    authText = Text.literal("This seems to be the first time you're connecting!\n")
                        .append(Text.literal("Visit "))
                        .append(Text.literal(url).formatted(Formatting.BLUE))
                        .append(Text.literal(" in your web browser to connect your Flashii ID.\n\nYour link code is: "))
                        .append(Text.literal(code).formatted(Formatting.LIGHT_PURPLE))
                        .append(Text.literal("\n\nAfter you've approved the attempt, connect to the server again and you should be good to go."));
                } else {
                    authText = Text.literal("Flashii authentication server returned an unknown response, yell at flashwave about this.").formatted(Formatting.RED);
                }
            }
        } catch(Exception ex) {
            authText = Text.literal("There was a serious problem during authentication, yell at flashwave about this.").formatted(Formatting.RED);
            ex.printStackTrace();
        }

        if(authText != null) {
            cir.setReturnValue(authText);
            cir.cancel();
        }
    }
}
