package net.flashii.mcexts;

import java.lang.reflect.Type;
import java.util.HashMap;
import com.google.gson.JsonArray;
import com.google.gson.JsonDeserializationContext;
import com.google.gson.JsonDeserializer;
import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonParseException;
import com.google.gson.JsonPrimitive;

public class RPCPayloadDeserialiser implements JsonDeserializer<RPCPayload> {
    @Override
    public RPCPayload deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context)
        throws JsonParseException  {
        JsonObject obj = json.getAsJsonObject();

        String name = obj.get("name").getAsString();
        JsonArray attrElems = obj.get("attrs").getAsJsonArray();

        HashMap<String, Object> attrs = new HashMap<>();
        for(JsonElement attrElem : attrElems) {
            JsonObject attrObj = attrElem.getAsJsonObject();
            JsonPrimitive attrValuePrimitive = attrObj.get("value").getAsJsonPrimitive();
            Object attrValue = null;

            if(attrValuePrimitive.isBoolean())
                attrValue = attrValuePrimitive.getAsBoolean();
            else if(attrValuePrimitive.isString())
                attrValue = attrValuePrimitive.getAsString();
            else if(attrValuePrimitive.isNumber()) // there's gotta be a better way of doing this
                attrValue = attrValuePrimitive.getAsInt();

            if(attrValue != null)
                attrs.put(attrObj.get("name").getAsString(), attrValue);
        }

        return new RPCPayload(name, attrs);
    }
}
